==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/SocialactivityCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Socialactivity;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SocialactivityRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class SocialactivityCollectionRequest extends CollectionPageEntityRequest<Socialactivity, SocialactivityRequest>{

    protected ContextPath contextPath;

    public SocialactivityCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Socialactivity.class, cp -> new SocialactivityRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public ConnectionCollectionRequest socialactivity_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("socialactivity_connections2"), Optional.empty());
    }

    public ConnectionRequest socialactivity_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("socialactivity_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest socialActivity_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("SocialActivity_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest socialActivity_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("SocialActivity_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest socialActivity_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("SocialActivity_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest socialActivity_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("SocialActivity_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest socialactivity_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("socialactivity_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest socialactivity_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("socialactivity_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest socialActivity_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SocialActivity_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest socialActivity_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SocialActivity_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_socialactivity() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_socialactivity"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_socialactivity(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_socialactivity").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest socialActivity_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("SocialActivity_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest socialActivity_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("SocialActivity_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest socialactivity_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("socialactivity_connections1"), Optional.empty());
    }

    public ConnectionRequest socialactivity_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("socialactivity_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest socialActivity_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("SocialActivity_Annotation"), Optional.empty());
    }

    public AnnotationRequest socialActivity_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("SocialActivity_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest socialActivity_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SocialActivity_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest socialActivity_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SocialActivity_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest socialActivity_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SocialActivity_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest socialActivity_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SocialActivity_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest socialActivity_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("SocialActivity_QueueItem"), Optional.empty());
    }

    public QueueitemRequest socialActivity_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("SocialActivity_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest socialactivity_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("socialactivity_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest socialactivity_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("socialactivity_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/SocialactivityCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Socialactivity;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SocialactivityRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class SocialactivityCollectionRequest extends CollectionPageEntityRequest<Socialactivity, SocialactivityRequest>{

    protected ContextPath contextPath;

    public SocialactivityCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Socialactivity.class, cp -> new SocialactivityRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public ConnectionCollectionRequest socialactivity_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("socialactivity_connections2"), Optional.empty());
    }

    public ConnectionRequest socialactivity_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("socialactivity_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest socialActivity_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("SocialActivity_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest socialActivity_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("SocialActivity_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest socialActivity_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("SocialActivity_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest socialActivity_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("SocialActivity_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest socialactivity_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("socialactivity_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest socialactivity_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("socialactivity_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest socialActivity_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SocialActivity_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest socialActivity_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SocialActivity_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_socialactivity() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_socialactivity"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_socialactivity(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_socialactivity").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest socialActivity_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("SocialActivity_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest socialActivity_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("SocialActivity_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest socialactivity_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("socialactivity_connections1"), Optional.empty());
    }

    public ConnectionRequest socialactivity_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("socialactivity_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest socialActivity_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("SocialActivity_Annotation"), Optional.empty());
    }

    public AnnotationRequest socialActivity_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("SocialActivity_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest socialActivity_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SocialActivity_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest socialActivity_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SocialActivity_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest socialActivity_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SocialActivity_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest socialActivity_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SocialActivity_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest socialActivity_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("SocialActivity_QueueItem"), Optional.empty());
    }

    public QueueitemRequest socialActivity_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("SocialActivity_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest socialactivity_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("socialactivity_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest socialactivity_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("socialactivity_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}
